@@ -34,14 +34,25 @@ all the user actions to CEM fo logging/mentor input/game input."
 #include "../jammo.h"
 #include "gui.h"
 #include "singinggame.h"
+#include "jammo-collaboration-pair-composition.h"
 
-/*Chum is like state-machine*/
-int state_of_chum=SCREEN_WELCOME;
-jammo_song* current_song;  /*for karaoke game*/
+static int state_of_chum=SCREEN_WELCOME;
+static jammo_song* current_song;  /*for karaoke game*/
+
+
+static JammoCollaborationPairComposition* static_pair_composition = NULL;
+
+JammoCollaborationPairComposition* chum_get_pair_composition() {
+	return static_pair_composition;
+}
+
+void chum_set_pair_composition(JammoCollaborationPairComposition* pc) {
+	static_pair_composition=pc;
+}
 
 //This is not same than language from profile (which affects speech of mentor)
 //This is only when user wants sing a song in different language.
-char* selected_language=NULL;
+static char* selected_language=NULL;
 
 const char* chum_get_selected_language(){
 	return selected_language;
@@ -65,7 +76,7 @@ gboolean chum_get_duetto(){
 
 
 //FALSE means advanced_game
-static gboolean chum_easy_game = TRUE;
+static gboolean chum_easy_game = FALSE;
 gboolean chum_is_easy_game(){
   return chum_easy_game;
 }
@@ -91,8 +102,8 @@ char *name_of_states[] ={ "SCREEN_WELCOME",
                           "SCREEN_FROM_CUPBOARD"};
 
 
-gboolean multiplaying=FALSE; 
-gint number_of_themes = 0;
+
+static gint number_of_themes = 0;
 gint chum_get_number_of_themes(){
 return number_of_themes;
 }
