@@ -105,41 +105,55 @@ static gboolean cupboard_composition_icon_clicked(TangleButton *tanglebutton, gp
 	return FALSE;
 }
 
-/*Read the first row of file:
-Caller must handle freeing.
-When compositions will be saved in json, this will be obsolated. TODO
+/*
+Check icon_filename from given json-file
+Will return NULL, if
+ *file not found
+ *file is folder
+
+User should free memory after usage
 */
-static gchar* give_first_row_of_file(gchar* filename){
-	//printf("give_first_row_of_file: filename='%s'\n",filename);
-	FILE *ifp;
-	ifp = fopen(filename, "r");
-	g_return_val_if_fail(ifp != NULL, FALSE);
+static gchar* icon_filename_from_json(char* filename){
+  JsonParser *parser;
+  parser = json_parser_new ();
+  g_assert (JSON_IS_PARSER (parser));
 
-	int bytes_read;
-	size_t nbytes = 200;
-	char *my_string;
-	my_string = (char *) malloc (nbytes + 1);
+  GError *error = NULL;
+  if (!json_parser_load_from_file (parser, filename, &error))
+        {
+          //g_print ("Error: %s\n", error->message);
+          g_error_free (error);
+          g_object_unref (parser);
+          return NULL;
+        }
 
-	bytes_read = getline (&my_string, &nbytes, ifp);
+  JsonNode *root;
+  JsonObject *object;
 
-	char* row = malloc (bytes_read + 1);
-	strncpy(row, my_string, strlen(my_string)-1); //throw end-of-line away
-	row[strlen(my_string)-1]='\0';                //Add string terminator
+  g_assert (NULL != json_parser_get_root (parser));
 
-	g_free(my_string);
-	fclose(ifp);
+  //g_print ("checking root node is an object...\n");
+  root = json_parser_get_root (parser);
+  g_assert_cmpint (JSON_NODE_TYPE (root), ==, JSON_NODE_OBJECT);
 
-	//printf("give_first_row_of_file: will return='%s'\n",row);
-	return row;
+  object = json_node_get_object (root);
+  g_assert (object != NULL);
+
+
+  G_CONST_RETURN gchar *value = json_object_get_string_member(object ,"icon");
+  //printf("parser got '%s'\n",value);
+  gchar* name =  g_strdup_printf("%s",value);
+
+  g_object_unref (parser);
+  return name;
 }
 
 
 /*
-Check asked char*-value for given json-file
+Check path, record, language from given json-file
 Will return NULL, if
  *file not found
  *file is folder
- *invalid elemet was asked
 
 User should free memory after usage
 */
@@ -235,7 +249,7 @@ static void load_icons_from_disk (){
 		//printf("readed '%s'\n",(char*)l->data);
 		ClutterActor* icon;
 
-		gchar* icon_filename = give_first_row_of_file((gchar*)l->data);
+		gchar* icon_filename = icon_filename_from_json((gchar*)l->data);
 		//printf("got icon_filename='%s'\n", icon_filename);
 
 		ClutterActor* image = clutter_texture_new_from_file(icon_filename, NULL);
