@@ -31,7 +31,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <clutter/clutter.h>
-#include <math.h>
+
 
 #include "../../meam/jammo-meam.h"
 #include "../../meam/jammo-instrument-track.h"
@@ -43,6 +43,8 @@
 
 #include "midi_editor.h"
 
+#include "slider_helper.h" //There are ranges for slider
+
 
 //For keyboard
 static int UPPER_OCTAVE=3;
@@ -90,14 +92,6 @@ char instrument_gui_get_transpose() {
 	return 'c';
 }
 
-//For slider
-#define RANGE 2.0
-// X coordinates of playing area
-#define RIGHT_X 599.0
-#define LEFT_X 0.0
-#define OCTAVE_ON_SCREEN ((RIGHT_X - LEFT_X)/RANGE)
-#define BASE_FREQUENCY 130.81
-
 //These we get as parameter and will return after use
 static JammoSequencer* static_sequencer;
 static JammoMiditrackView* static_jammo_miditrack_view;
@@ -113,6 +107,8 @@ static JammoSequencer* ad_hoc_sequencer;
 //State of recording
 static gboolean recording;
 
+static gboolean playing;
+
 //This is pointer to marker of slider (we need to change which slider-track is moving it)
 static ClutterActor* slider_marker;
 
@@ -263,13 +259,13 @@ void instrument_goeditor_clicked (TangleAction *action, GObject *source, const g
 }
 
 //////////////////////////
-
+static gulong handler_for_update_marker = 0;
 
 //slider-specific
 //---------------
 static void update_marker(JammoSliderTrack* track, gfloat frequency, gpointer none) {
-		printf("update_marker: Frequency %f\n",frequency);
-		gfloat x = OCTAVE_ON_SCREEN * log2(frequency/BASE_FREQUENCY);
+		printf("update_marker: '%p' Frequency %f\n",track,frequency);
+		gfloat x = freq_to_coordinate(frequency);
 		if (frequency==0) //-> x=-inf
 			x=0.0;
 		printf("X: %f\n",x);
@@ -282,7 +278,7 @@ gboolean instrument_gui_slider_handler (ClutterActor *actor, ClutterEvent *event
 	clutter_event_get_coords (event, &x_release, &y_release);
 	//printf("slider_handler: X=%d\n",(gint)x_release);
 
-	freq = BASE_FREQUENCY*pow(2.0, x_release/OCTAVE_ON_SCREEN);
+	freq = coordinate_to_freq((gint)x_release);
 	//printf("Freq: %f\n",freq);
 
 	JammoSliderTrack* slider_track;
@@ -321,6 +317,7 @@ void instrument_metronome_clicked (TangleAction *action, GObject *source, const
 
 static void end_jamming() {
 	jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
+	g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
 
 	//hide instrument_view
 	ClutterActor* mainview;
@@ -330,6 +327,22 @@ static void end_jamming() {
 
 
 
+//TODO
+void instrument_mentor_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	printf("instrument MENTOR clicked\n");
+}
+
+
+//TODO
+void instrument_gohome_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	printf("instrument_gohome_clicked\n");
+	end_jamming();
+
+	//show sequencer. TODO: go main-menu, not sequencer-view
+	ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
+	clutter_actor_show(view);
+}
+
 void instrument_gosequencer_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	printf("instrument_gosequencer_clicked\n");
 	end_jamming();
@@ -339,16 +352,32 @@ void instrument_gosequencer_clicked (TangleAction *action, GObject *source, cons
 	clutter_actor_show(view);
 }
 
-
 void instrument_play_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	printf("play pressed\n");
 
+	if (recording) {
+		printf("STOPping recording first\n");
+	jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
+	}
+
+	if (playing) {
+		printf("Already playing -> stop\n");
+		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
+		return;
+	}
+
+	printf("Playing sequencer\n");
+	playing=TRUE;
+	//If user has pressed play-button during record, we need handle this manually
+	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("instrument_play")),TRUE);
+
 	//stop ad_hoc.
 	jammo_sequencer_stop (JAMMO_SEQUENCER (ad_hoc_sequencer));
 
 	if (static_slider_track) {
 		//Change this slider_track to move slider_marker.
-		g_signal_connect (static_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
+		g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
+		handler_for_update_marker = g_signal_connect (static_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
 	}
 
 	//Start real-sequencer
@@ -362,46 +391,57 @@ void instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)
 	if (recording) {
 		printf("STOP recording\n");
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
+		return;
 	}
 
+	if (playing) {
+		printf("STOP playing and start recording\n");
+		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
+	}
+
+	printf("START recording\n");
+	recording = TRUE;
+
+	//If user has pressed record-button during play, we need handle this manually
+	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("instrument_record")),TRUE);
+
+
+	//TODO, there should be some prelude, or precount with metronome
+
+
+	//stop ad_hoc.
+	jammo_sequencer_stop (JAMMO_SEQUENCER (ad_hoc_sequencer));
+
+	//Slider:
+	if (static_jammo_miditrack_view==NULL) {
+		//clean original
+		jammo_slider_track_set_event_list(JAMMO_SLIDER_TRACK(static_slider_track),NULL);
+
+		//set to realtime
+		jammo_slider_track_set_recording (JAMMO_SLIDER_TRACK(static_slider_track), TRUE);
+
+		//Change this slider_track to move slider_marker.
+		g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
+		handler_for_update_marker = g_signal_connect (static_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
+
+		printf("Recording NOW\n");
+	}
+
+
+	//Keyboard:
 	else {
-		printf("START recording\n");
-		recording = TRUE;
-		//TODO, there should be some prelude, or precount with metronome
+		//clean original
+		JammoTrack* track;
+		g_object_get(static_jammo_miditrack_view,"track",&track,NULL);
+		jammo_instrument_track_set_event_list(JAMMO_INSTRUMENT_TRACK(track),NULL);
 
-
-		//stop ad_hoc.
-		jammo_sequencer_stop (JAMMO_SEQUENCER (ad_hoc_sequencer));
-
-		//Slider:
-		if (static_jammo_miditrack_view==NULL) {
-			//clean original
-			jammo_slider_track_set_event_list(JAMMO_SLIDER_TRACK(static_slider_track),NULL);
-
-			//set to realtime
-			jammo_slider_track_set_recording (JAMMO_SLIDER_TRACK(static_slider_track), TRUE);
-
-			//Change this slider_track to move slider_marker.
-			g_signal_connect (static_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
-			printf("nauhoitus alkaa\n");
-		}
-
-
-		//Keyboard:
-		else {
-			//clean original
-			JammoTrack* track;
-			g_object_get(static_jammo_miditrack_view,"track",&track,NULL);
-			jammo_instrument_track_set_event_list(JAMMO_INSTRUMENT_TRACK(track),NULL);
-
-			//set to realtime
-			jammo_instrument_track_set_realtime (JAMMO_INSTRUMENT_TRACK(track), TRUE);
-		}
-
-		//Now all content in sequencer will play and instrument_track is recording
-		jammo_sequencer_play (JAMMO_SEQUENCER (static_sequencer));
+		//set to realtime
+		jammo_instrument_track_set_realtime (JAMMO_INSTRUMENT_TRACK(track), TRUE);
 	}
 
+	//Now all content in sequencer will play and instrument_track is recording
+	jammo_sequencer_play (JAMMO_SEQUENCER (static_sequencer));
+
 }
 
 //TODO: this signal should be removed when changing view.
@@ -415,7 +455,8 @@ static void instrument_gui_on_sequencer_stopped(JammoSequencer* sequencer, gpoin
 		//If playback has just stopped, this is already FALSE, but it is not harm
 		jammo_slider_track_set_recording (JAMMO_SLIDER_TRACK(static_slider_track), FALSE);
 		//Change this slider_track to move slider_marker.
-		g_signal_connect (ad_hoc_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
+		//g_signal_handler_disconnect (static_slider_track,handler_for_update_marker); //This is not assigned
+		handler_for_update_marker = g_signal_connect (ad_hoc_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
 	}
 
 
@@ -440,7 +481,11 @@ static void instrument_gui_on_sequencer_stopped(JammoSequencer* sequencer, gpoin
 	}
 
 	//else = playback has just stopped
+	playing=FALSE;
 
+	//Both play and rec buttons should be non-pressed
+	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("instrument_record")),FALSE);
+	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("instrument_play")),FALSE);
 
 	//Start ad-hoc-sequencer
 	jammo_sequencer_play  (JAMMO_SEQUENCER (ad_hoc_sequencer));
@@ -465,6 +510,7 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* p
 	clutter_actor_show(view);
 
 	recording = FALSE;
+	playing = FALSE;
 
 	ad_hoc_sequencer = jammo_sequencer_new ();
 	static_slider_track = NULL;
@@ -473,8 +519,9 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* p
 	if (slider_container){
 		printf("starting slider\n");
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-two-rows-keyboard")); //this will also hide go_editor-button
+		clutter_actor_hide(jammo_get_actor_by_id("instrument-drumset"));
+
 
-		//This could be not-visible if midikeyboard has used
 		clutter_actor_show(jammo_get_actor_by_id("instrument-slider"));
 
 		static_slider_track = JAMMO_SLIDER_TRACK(g_object_get_data(G_OBJECT(slider_container),"track"));
@@ -484,9 +531,12 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* p
 		g_object_get(static_slider_track,"slider-type",&type,NULL);
 
 		ad_hoc_slider_track = jammo_slider_track_new (type);
-		jammo_slider_track_set_recording (ad_hoc_slider_track, TRUE);
 		jammo_sequencer_add_track (ad_hoc_sequencer, JAMMO_TRACK (ad_hoc_slider_track));
-		g_signal_connect (ad_hoc_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
+
+		//Track must be added to sequencer before changing it recording
+		jammo_slider_track_set_recording (ad_hoc_slider_track, TRUE);
+
+		handler_for_update_marker = g_signal_connect (ad_hoc_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
 
 		//Marker = cursor for slider frequency.
 		slider_marker =  jammo_get_actor_by_id("instrument-slider-marker");
@@ -497,15 +547,9 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* p
 	}
 
 	else {
-		//This could be not-visible if slider has used
-		clutter_actor_show(jammo_get_actor_by_id("instrument-two-rows-keyboard"));
-
-		clutter_actor_hide(jammo_get_actor_by_id("instrument-slider"));
-
 		//Take miditrack_view safe to static variable
 		static_jammo_miditrack_view=miditrack_view;
 
-
 		JammoTrack* track;
 		g_object_get(miditrack_view,"track",&track,NULL);
 		g_signal_connect (track, "report-note", G_CALLBACK (visualize_playback),NULL);
@@ -513,10 +557,19 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, JammoSequencer* p
 		int type;
 		g_object_get(track,"instrument-type",&type,NULL);
 
-		ad_hoc_instrument_track = jammo_instrument_track_new (type);
+		clutter_actor_hide(jammo_get_actor_by_id("instrument-slider"));
+		clutter_actor_hide(jammo_get_actor_by_id("instrument-two-rows-keyboard"));
+		clutter_actor_hide(jammo_get_actor_by_id("instrument-drumset"));
+		if (type==JAMMO_INSTRUMENT_TYPE_DRUMKIT)
+			clutter_actor_show(jammo_get_actor_by_id("instrument-drumset"));
+		else
+			clutter_actor_show(jammo_get_actor_by_id("instrument-two-rows-keyboard"));
 
-		jammo_instrument_track_set_realtime (ad_hoc_instrument_track, TRUE);
+		ad_hoc_instrument_track = jammo_instrument_track_new (type);
 		jammo_sequencer_add_track (ad_hoc_sequencer, JAMMO_TRACK (ad_hoc_instrument_track));
+
+		//Track must be added to sequencer before changing it recording
+		jammo_instrument_track_set_realtime (ad_hoc_instrument_track, TRUE);
 	}
 
 
