@@ -43,8 +43,11 @@ static const ClutterColor red = { 255, 0, 0, 128 }; //for cursor
 static gfloat height_of_grid_slot = 64.0;  //non-zoomed grid-size (700px/64 = 11 slots.  400px/64= 6 slots)
 static gfloat width_of_grid_slot = 64.0;
 
-static ClutterActor* piano_roll;
+static ClutterActor* static_piano_roll_in;   //zoomed_in version of piano_roll
+static ClutterActor* static_piano_roll_out;  //zoomed_out version of piano_roll
+
 static JammoSequencer* static_sequencer;
+static ClutterActor* static_cursor;
 
 //we got these as parameters and are returning them after use
 static JammoMiditrackView* static_jammo_miditrack_view; //Editor doesn't make own miditrack-view, but uses existing!
@@ -85,41 +88,57 @@ void midi_editor_start_with_filename(gchar* note_file){
 
 
 /*
-	Change zoom-button state. TODO
-	Toggling between in/out. TODO
-	Zoom track. Done.
-	(hide grid?)
-	Zoom piano_roll. Done.
-
-	FIXME: if scrolled very bottom and zoomed in, there are first messy
+	Zoom track.
+	*hide grid?
+	*disable editing?
 */
 void midieditor_zoom_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
 
+	gfloat width=0;
+	gfloat height=0;
+
+	if (tangle_button_get_selected(tanglebutton)) { //Zoom Out;
+		printf("zoom out\n");
+		//if scrolled very bottom and zoomed out, track is ouside of view
+		g_object_set(jammo_get_actor_by_id( "midieditor-track-scroller"), "scrolling-offset-x", 0.0, "scrolling-offset-y", 0.0, NULL);
+
+		width = 700.0;
+		height = 400.0;
+
+		//Piano-roll
+		clutter_actor_hide(static_piano_roll_in);
+		clutter_actor_show(static_piano_roll_out);
+	}
+	else {  //Zoom In:
+		printf("zoom in\n");
+		guint slots;
+		g_object_get(static_jammo_miditrack_view,"n-slots", &slots, NULL);
+
+		width = slots*width_of_grid_slot;
+		height = (highest_note-lowest_note+1) *height_of_grid_slot;
+
+		//Piano-roll
+		clutter_actor_hide(static_piano_roll_out);
+		clutter_actor_show(static_piano_roll_in);
+	}
+
 	//Track
-	//Will resize total area of miditrack to 700x400. (width can vary, but height should be 400)
-	jammo_miditrack_view_zoom_to_fit(static_jammo_miditrack_view,1400.0, 400.0);
+	jammo_miditrack_view_zoom_to_fit(static_jammo_miditrack_view,width, height);
 
-
-	//Piano-roll. Delete previous, make new with correct size.
-	ClutterActor* parent = clutter_actor_get_parent(piano_roll);
-	clutter_actor_destroy(piano_roll);
-
-	gfloat height;
-	g_object_get(static_jammo_miditrack_view, "slot-height", &height,NULL);
-
-	piano_roll = create_piano_roll(height,highest_note,lowest_note,FALSE);
-	clutter_container_add_actor(CLUTTER_CONTAINER(parent), piano_roll);
+	//Cursor
+	clutter_actor_set_size(static_cursor, width, 180.0); //Area where cursor is moving.
 }
 
 /**
  * JSON callback
-
- TODO: stopping
- TODO: changing button texture
  */
 void midieditor_playstop_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
+	//Always stop sequencer
 	jammo_sequencer_stop(JAMMO_SEQUENCER(static_sequencer));
-	jammo_sequencer_play(JAMMO_SEQUENCER(static_sequencer));
+
+	if (tangle_button_get_selected(tanglebutton)) {  //Play pressed
+		jammo_sequencer_play(JAMMO_SEQUENCER(static_sequencer));
+	}
 }
 
 
@@ -127,14 +146,19 @@ void midieditor_playstop_clicked  (TangleButton *tanglebutton, gpointer user_dat
 /**
  * This function set/unset pencil_mode.
  * JSON callback
- 
- TODO: changing button texture
  */
 void midieditor_pencil_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
-
 	jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, (!jammo_miditrack_view_get_pen_mode(static_jammo_miditrack_view)));
 }
 
+/**
+ * This function set/unset eraser_mode.
+ * JSON callback
+ */
+void midieditor_eraser_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
+	//jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, (!jammo_miditrack_view_get_pen_mode(static_jammo_miditrack_view)));
+}
+
 /**
 TODO
 */
@@ -142,6 +166,13 @@ void midieditor_finder_clicked (TangleButton *tanglebutton, gpointer user_data)
 printf("finder clicked\n");
 }
 
+/**
+TODO
+*/
+void midieditor_quantanize_clicked (TangleButton *tanglebutton, gpointer user_data)  {
+printf("midieditor-quantanize clicked\n");
+}
+
 
 void midieditor_exit_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
 	printf("midieditor_exit_clicked\n");
@@ -150,6 +181,7 @@ void midieditor_exit_clicked  (TangleButton *tanglebutton, gpointer user_data)
 		exit(0);
 	}
 
+	jammo_sequencer_stop(static_sequencer);
 	//return miditrack-view to original parent and original attributes
 	ClutterActor* actor = CLUTTER_ACTOR(static_jammo_miditrack_view);
 	g_object_ref(actor);
@@ -173,8 +205,11 @@ void midieditor_exit_clicked  (TangleButton *tanglebutton, gpointer user_data)
 	ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
 	clutter_actor_show(view);
 
-	//Delete piano_roll (it is generated each time)
-	clutter_actor_destroy(piano_roll);
+	//Delete piano_roll (actually its container and scroller and both piano-rolls)
+	clutter_actor_destroy(clutter_actor_get_parent(static_piano_roll_in));
+
+	//Cursor is generated each time.
+	clutter_actor_destroy(static_cursor);
 }
 
 
@@ -215,10 +250,8 @@ static void start_midi_editor(void) {
 
 	//CHUM (graphical)
 	ClutterActor* container_for_piano_roll;
-	ClutterActor* scrolling_actor;   //for track
-	ClutterActor* scrolling_actor2;  //for piano_roll
-	ClutterActor* texture;
-	ClutterActor* cursor;
+	ClutterActor* scrolling_actor_for_piano_roll;
+	ClutterActor* texture_for_cursor;
 
 	ClutterActor* container_for_track =  jammo_get_actor_by_id("midieditor-container-for-track");
 
@@ -238,31 +271,36 @@ static void start_midi_editor(void) {
 
 	g_object_unref(actor);
 
-	scrolling_actor = jammo_get_actor_by_id( "midieditor-track-scroller");
+	//PIANO-ROLL on left
+	//We make two different size piano_roll (zoomed-in and zoomed-out)
 
-	//PianoRoll on left
 	//We need container for piano roll because we want change content of piano_roll (e.g. when zooming)
 	container_for_piano_roll = tangle_widget_new();
-	scrolling_actor2 = tangle_scrolling_actor_new(container_for_piano_roll);
-	clutter_actor_set_position(scrolling_actor2, 0.0, 0.0);
-	clutter_actor_set_size(scrolling_actor2, 100.0, 400.0);
-	tangle_widget_add(TANGLE_WIDGET(view), scrolling_actor2, NULL);
 
-	piano_roll = create_piano_roll(height_of_grid_slot,highest_note,lowest_note,TRUE);
-	tangle_widget_add(TANGLE_WIDGET(container_for_piano_roll), piano_roll, NULL);
+	static_piano_roll_in = create_piano_roll(height_of_grid_slot,highest_note,lowest_note,FALSE);
+	static_piano_roll_out = create_piano_roll(400.0/(highest_note-lowest_note+1),highest_note,lowest_note,FALSE);
+	tangle_widget_add(TANGLE_WIDGET(container_for_piano_roll), static_piano_roll_in, NULL);
+	tangle_widget_add(TANGLE_WIDGET(container_for_piano_roll), static_piano_roll_out, NULL);
+	clutter_actor_hide(static_piano_roll_out); //Hide zoomed-out version
 
 
+	scrolling_actor_for_piano_roll = tangle_scrolling_actor_new(container_for_piano_roll);
+	clutter_actor_set_position(scrolling_actor_for_piano_roll, 0.0, 0.0);
+	clutter_actor_set_size(scrolling_actor_for_piano_roll, 100.0, 400.0);
+	tangle_widget_add(TANGLE_WIDGET(view), scrolling_actor_for_piano_roll, NULL);
+
 	//Bind piano_roll and grid together.
-	tangle_binding_new(G_OBJECT(scrolling_actor2), "scrolling-offset-y", G_OBJECT(scrolling_actor), "scrolling-offset-y");
+	tangle_binding_new(G_OBJECT(scrolling_actor_for_piano_roll), "scrolling-offset-y",
+   G_OBJECT(jammo_get_actor_by_id( "midieditor-track-scroller")), "scrolling-offset-y");
 
 
-	//Cursor. TODO:When this is free'ed?
-	texture = clutter_rectangle_new_with_color(&red);
-	clutter_actor_set_size(texture, 10.0, 78.0);
-	cursor = jammo_cursor_new(static_sequencer, texture);
-	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
-	clutter_actor_set_position(cursor, 0.0, 200.0);
-	clutter_actor_set_size(cursor, 64.0*25, 180.0); //width=grid_width*slot_numbers, height (not used) = grid_height*(high-low)
-	tangle_widget_add(TANGLE_WIDGET(view), cursor, NULL);
+	//Cursor
+	texture_for_cursor = clutter_rectangle_new_with_color(&red);
+	clutter_actor_set_size(texture_for_cursor, 10.0, height_of_grid_slot *(highest_note-lowest_note+1)); //Texture size
+	static_cursor = jammo_cursor_new(static_sequencer, texture_for_cursor);
+	tangle_actor_set_depth_position(TANGLE_ACTOR(static_cursor), 1);
+	clutter_actor_set_position(static_cursor, 0.0, 0.0);
+	clutter_actor_set_size(static_cursor, width_of_grid_slot*slots, 180.0); //Area where cursor is moving.
+	tangle_widget_add(TANGLE_WIDGET(container_for_track), static_cursor, NULL);
 }
 
