@@ -43,71 +43,65 @@ static gint tracks_in_use = 0;
 
 static JammoSequencer* sequencer; // for playing the tracks;
 
-static gfloat VOLUME_MAX = 100; //? FIX
 
 static gboolean METRONOME_STATE = FALSE;
 
 
-static gboolean pressed_sequencer_button_mute(ClutterActor *actor, ClutterEvent *event, gpointer data);
-static ClutterAnimation * animate_buttonpress_release(ClutterActor *actor);
-static gboolean pressed_sequencer_button_volume(ClutterActor *actor, ClutterEvent *event, gpointer data);
-static gboolean pressed_sequencer_button_track_label(ClutterActor *actor, ClutterEvent *event, gpointer data);
-
-
-
+static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
+static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
+static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data);
 
+//We want toggle this up, when next is clicked
+TangleButton* last_pressed_volume_button = NULL;
 
 /*
  * Creates and returns SequencerTrackView struct
  */
 static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
-    ClutterActor *track_view, char *track_view_type, void* track) {
+    ClutterActor *track_view, gint track_view_type, gboolean muted) {
 
-	ClutterActor* mute_button = clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute.png", NULL);
+	ClutterActor* mute_button = tangle_button_new_selectable_with_background_actors (
+     clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute.png", NULL), /* normal */
+     clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute_pressed.png", NULL),  /* interactive */
+     clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute_pressed.png", NULL)); /* selected */
 	clutter_actor_set_size(mute_button, track_height-4,track_height-4); //it is square. Four pixels marginal
-	ClutterActor* volume_button = clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume.png", NULL);
+	tangle_button_set_selected(TANGLE_BUTTON(mute_button),muted);
+
+	ClutterActor* volume_button =  tangle_button_new_selectable_with_background_actors (
+     clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume.png", NULL), /* normal */
+     clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume_pressed.png", NULL),  /* interactive */
+     clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume_pressed.png", NULL)); /* selected */
+
 	clutter_actor_set_size(volume_button, track_height-4,track_height-4); //it is square. Four pixels marginal
 
 	clutter_actor_set_height(label,track_height-4); //this is not square, so change oly height
 
 	SequencerTrackView *view = malloc(sizeof(SequencerTrackView));
 	view->control_panel = tangle_widget_new();
-	view->label = label;
-	view->mute_button = mute_button;
-	view->volume_button = volume_button;
 	view->track_view = track_view;
-	view->position = -1;   //This is used only for volume_slider: FIXME: remove
-	view->muted = FALSE;   //Track will know if it is muted. FIXME: remove
-	view->volume_pressed_down = FALSE;
-	view->volume_level = VOLUME_MAX;  //Track will know own volume_level. FIXME: remove
-	view->track_type = track_view_type;
+	view->track_type = track_view_type; //can this be checked inside meam-track (which is inside track_view)?
 
-	tangle_widget_add(TANGLE_WIDGET(view->control_panel), view->label,NULL);
-	tangle_widget_add(TANGLE_WIDGET(view->control_panel), view->mute_button,NULL);
-	tangle_widget_add(TANGLE_WIDGET(view->control_panel), view->volume_button,NULL);
+	tangle_widget_add(TANGLE_WIDGET(view->control_panel), label,NULL);
+	tangle_widget_add(TANGLE_WIDGET(view->control_panel), mute_button,NULL);
+	tangle_widget_add(TANGLE_WIDGET(view->control_panel), volume_button,NULL);
 
 	gfloat x=0;
-	clutter_actor_set_position(view->label, x, 0.0);
-	x += 2 +  clutter_actor_get_width(view->label);
+	clutter_actor_set_position(label, x, 0.0);
+	x += 2 +  clutter_actor_get_width(label);
 
-	clutter_actor_set_position(view->mute_button, x, 0.0);
-	x += 2.0 + clutter_actor_get_width(view->mute_button);
+	clutter_actor_set_position(mute_button, x, 0.0);
+	x += 2.0 + clutter_actor_get_width(mute_button);
 
-	clutter_actor_set_position(view->volume_button, x, 0.0);
+	clutter_actor_set_position(volume_button, x, 0.0);
 
-	g_signal_connect(CLUTTER_ACTOR(view->label), "button_press_event", G_CALLBACK(pressed_sequencer_button_track_label), view);
-	g_signal_connect(CLUTTER_ACTOR(view->mute_button), "button_press_event", G_CALLBACK(pressed_sequencer_button_mute), view);
-	g_signal_connect(CLUTTER_ACTOR(view->volume_button), "button_press_event", G_CALLBACK(pressed_sequencer_button_volume), view);
-
-
-
-	clutter_actor_set_reactive(view->label, TRUE);
-	clutter_actor_set_reactive(view->mute_button, TRUE);
-	clutter_actor_set_reactive(view->volume_button, TRUE);
+	g_signal_connect(CLUTTER_ACTOR(label), "clicked", G_CALLBACK(pressed_sequencer_button_track_label), view);
+	g_signal_connect(CLUTTER_ACTOR(mute_button), "clicked", G_CALLBACK(pressed_sequencer_button_mute), view);
+	g_signal_connect(CLUTTER_ACTOR(volume_button), "clicked", G_CALLBACK(pressed_sequencer_button_volume), view);
 
 	return view;
 }
 
+#define Y_OFFSET 48
 /* Adds STV into array & container and positions it.
  */
 static void sequencer_track_view_add(SequencerTrackView *track_view) {
@@ -115,75 +109,102 @@ static void sequencer_track_view_add(SequencerTrackView *track_view) {
 
 	//Add this tracks control_panel (volume buttons etc)
 	clutter_container_add_actor(CLUTTER_CONTAINER(jammo_get_actor_by_id("fullsequencer-track-control-panel")), track_view->control_panel);
-	clutter_actor_set_y(track_view->control_panel, track_height * tracks_in_use);
+	clutter_actor_set_y(track_view->control_panel, track_height * tracks_in_use + Y_OFFSET);
 
 	//Add track to container
 	ClutterActor* track_container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
 	clutter_container_add_actor(CLUTTER_CONTAINER(track_container), track_view->track_view);
 	clutter_actor_set_x(track_view->track_view, clutter_actor_get_x(track_view->track_view)+1);  //unless left border is not visible
-	clutter_actor_set_y(track_view->track_view, track_height * (tracks_in_use)+1);  //unless bottom border is not visible
+	clutter_actor_set_y(track_view->track_view, track_height * tracks_in_use + Y_OFFSET +1);  //unless bottom border is not visible
 
 	//Raise container's and scroller's height
 	clutter_actor_set_height(track_container,clutter_actor_get_height(track_container)+track_height);
 	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller-for-tracks");
-	clutter_actor_set_height(scrolling_actor, clutter_actor_get_height(track_container));
-	clutter_actor_set_height(texture_of_cursor, clutter_actor_get_height(track_container));
+	clutter_actor_set_height(scrolling_actor, clutter_actor_get_height(track_container) + Y_OFFSET);
+	clutter_actor_set_height(texture_of_cursor, clutter_actor_get_height(track_container) + Y_OFFSET);
 
-	track_view->position = tracks_in_use;
 	tracks_in_use++;
-	printf("Sequencer Track View placed in Position y: %f\n",
-         clutter_actor_get_y(track_view->control_panel));
 }
 
 
+//This contains lots of same rows than sequencer_track_view_add_with_type
+ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted) {
+	ClutterActor *label;
+	ClutterActor* track_view_actor = NULL; //This will be returned
+	SequencerTrackView *sequencer_track_view;
+
+	gchar* name_of_label_button="";
+	name_of_label_button = "/opt/jammo/sequencer/label_backingtrack.png";
+	label = tangle_button_new_with_background_actors (
+     clutter_texture_new_from_file(name_of_label_button, NULL), /* normal */
+     clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
+
+	track_view_actor = tangle_widget_new();
+	g_object_set_data (G_OBJECT(track_view_actor),"track",track);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
+	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, BACKING_TRACK_VIEW, muted);
+	sequencer_track_view_add(sequencer_track_view);
+	return track_view_actor;
+}
 
 /*
  * Adds given type of track view into sequencer view
  * Returns track_view_actor (jammo_track_view) of newly created sequencer_track_view
  * Returns NULL is askes invalid type.
  */
-ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type ) {
-	char *twt = track_view_type;
-	printf("Making '%s' track (duration: %" G_GUINT64_FORMAT ")\n",track_view_type, duration_of_tracks);
+ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gint optional_parameter) {
+	gint twt = track_view_type;
+	printf("Making '%d' track (duration: %" G_GUINT64_FORMAT ")\n",track_view_type, duration_of_tracks);
 
 	guint64 duration_of_one_slot = duration_of_tracks / number_of_slots;
 
-	ClutterActor *label = clutter_texture_new();
+	ClutterActor *label;
+	gchar* name_of_label_button="";
 	JammoTrack* track;
 
 	ClutterActor* track_view_actor = NULL; //This will be returned
 	SequencerTrackView *sequencer_track_view;
 
 	//Choose label-image:
-	if (strncmp(track_view_type,"DRUM_TRACK_VIEW",7)==0)
-		label = clutter_texture_new_from_file("/opt/jammo/sequencer/label_drum.png", NULL);
+	switch (track_view_type) {
+		case 	INSTRUMENT_TRACK_VIEW:
+			name_of_label_button = "/opt/jammo/sequencer/label_keyboard.png";
+			break;
 
-	else if (strncmp(track_view_type,"SLIDER_TRACK_VIEW",7)==0)
-		label = clutter_texture_new_from_file("/opt/jammo/sequencer/label_slider.png", NULL);
+		case DRUM_TRACK_VIEW:
+			name_of_label_button = "/opt/jammo/sequencer/label_drum.png";
+			break;
 
-	else if (strncmp(track_view_type,"AUDIO_TRACK_VIEW",7)==0)
-		label = clutter_texture_new_from_file("/opt/jammo/sequencer/label_audio.png", NULL);
+		case SLIDER_TRACK_VIEW:
+			name_of_label_button = "/opt/jammo/sequencer/label_slider.png";
+			break;
 
-	else if (strncmp(track_view_type,"LOOP_TRACK_VIEW",7)==0)
-		label = clutter_texture_new_from_file("/opt/jammo/sequencer/label_loop.png", NULL);
+		case AUDIO_TRACK_VIEW:
+			name_of_label_button = "/opt/jammo/sequencer/label_audio.png";
+			break;
 
-	else if (strncmp(track_view_type,"BACKING_TRACK_VIEW",7)==0)
-		label = clutter_texture_new_from_file("/opt/jammo/sequencer/label_backingtrack.png", NULL);
-
-	else if (strncmp(track_view_type,"KEYBOARD_TRACK_VIEW",7)==0)
-		label= clutter_texture_new_from_file("/opt/jammo/sequencer/label_keyboard.png", NULL);
-
-
-	else  { //Error-case
-		printf("Not detected track-view type\n");
+		case EDITING_TRACK_VIEW:
+			name_of_label_button = "/opt/jammo/sequencer/label_loop.png";
+			break;
+/*
+		case BACKING_TRACK_VIEW:
+			name_of_label_button = "/opt/jammo/sequencer/label_backingtrack.png";
+			break;
+*/
+		default:	 //Error-case
+			printf("sequencer_track_view_add_with_type: Not detected track-view type '%d'\n",track_view_type);
 		return NULL;
 	}
 
+	label = tangle_button_new_with_background_actors (
+     clutter_texture_new_from_file(name_of_label_button, NULL), /* normal */
+     clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
+
 
 	//Make instrument_track and miditrack_view
-	if (strncmp(track_view_type,"KEYBOARD_TRACK_VIEW",19)==0)
+	if (track_view_type == INSTRUMENT_TRACK_VIEW)
 		{
-		track = JAMMO_TRACK(jammo_instrument_track_new(JAMMO_INSTRUMENT_TYPE_UD)); //TODO. instrument_type
+		track = JAMMO_TRACK(jammo_instrument_track_new(optional_parameter));
 		jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(track),FALSE);
 
 		// TODO set transpose. Key of the song should be stored somewhere
@@ -199,9 +220,9 @@ ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type ) {
 
 
 	//Make slider_track and container for it
-	else if (strncmp(track_view_type,"SLIDER_TRACK_VIEW",13)==0)
+	else if (track_view_type == SLIDER_TRACK_VIEW)
 		{
-		track = JAMMO_TRACK(jammo_slider_track_new(JAMMO_SLIDER_TYPE_KARPLUS));//TODO. instrument_type
+		track = JAMMO_TRACK(jammo_slider_track_new(optional_parameter));
 		jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(track),FALSE);
 
 		track_view_actor = tangle_widget_new();
@@ -219,48 +240,22 @@ ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type ) {
 		g_object_set(track_view_actor, "line-every-nth-slot", 1, NULL);
 	}
 	
-	/* TODO: This is a quick test. Please, fix me. */
-	ClutterColor sample_color = { 255, 255, 0, 255 };
-	g_object_set(track_view_actor, "sample-color", &sample_color, NULL);
 
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
-	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, twt, track);
+	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, twt, muted);
 	sequencer_track_view_add(sequencer_track_view);
 	return track_view_actor;
 }
 
-static ClutterAnimation * animate_buttonpress_release(ClutterActor *actor) {
-	ClutterAnimation *anim = clutter_actor_animate (actor,          /* the actor to animate */
-			CLUTTER_LINEAR, /* the easing mode */
-			100,           /* the duration of the animation */
-			"scale-x", 1.0, /* final horizontal scaling factor */
-			"scale-y", 1.0, /* final vertical scaling factor */
-			"scale-gravity",CLUTTER_GRAVITY_CENTER,
-			NULL);
-	return anim;
-}
-
-static ClutterAnimation * animate_buttonpress_down(ClutterActor *actor) {
-	ClutterAnimation *anim = clutter_actor_animate (actor,          /* the actor to animate */
-			CLUTTER_LINEAR, /* the easing mode */
-			100,           /* the duration of the animation */
-			"scale-x", 0.80, /* final horizontal scaling factor */
-			"scale-y", 0.80, /* final vertical scaling factor */
-			"scale-gravity",CLUTTER_GRAVITY_CENTER,
-			NULL);
-	return anim;
-}
-
-
 /*
  * Event for pressing label on track, data points to track structure
  */
-static gboolean pressed_sequencer_button_track_label(ClutterActor *actor, ClutterEvent *event, gpointer data) {
+static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data) {
 
-	SequencerTrackView* track = (SequencerTrackView*)data;
+	SequencerTrackView* s_track_view = (SequencerTrackView*)data;
 
 	printf("Pressed track label\n");
-	if (JAMMO_IS_MIDITRACK_VIEW(track->track_view))
+	if (JAMMO_IS_MIDITRACK_VIEW(s_track_view->track_view))
 	{
 		printf("It is instrument track\n");
 		//We can start realtime jamming or midi-editor.
@@ -269,47 +264,48 @@ static gboolean pressed_sequencer_button_track_label(ClutterActor *actor, Clutte
 		//TODO: some way to go straight to editor.
 
 		//jamming
-		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track->track_view),sequencer, NULL); //NULL means no slider
+		instrument_gui_start(JAMMO_MIDITRACK_VIEW(s_track_view->track_view),sequencer, NULL); //NULL means no slider
 
 		//editor
 		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track->track_view));
 	}
-	else if (TANGLE_IS_WIDGET(track->track_view))
+	else if (TANGLE_IS_WIDGET(s_track_view->track_view))
 	{
-		printf("It is slider track\n");
-		instrument_gui_start(NULL,sequencer, TANGLE_WIDGET(track->track_view)); //NULL means no keyboard, but slider
+		printf("It is slider track or backing-track\n");
+		TangleWidget* container = TANGLE_WIDGET(s_track_view->track_view);
+		JammoTrack* track= JAMMO_TRACK(g_object_get_data(G_OBJECT(container),"track"));
+		if (JAMMO_IS_SLIDER_TRACK(track)) {
+			printf(" it is slider_track\n");
+			instrument_gui_start(NULL,sequencer, container); //NULL means no keyboard, but slider
+		}
+		else {
+			printf(" it is backing_track\n");
+		}
 	}
 
 	return TRUE;
 }
 
 
+/*JSON callback. TODO
+*/
+gboolean fullsequencer_mentor_clicked (TangleButton *tanglebutton, gpointer data)   {
+	printf("mentor clicked\n");
+	return TRUE;
+}
 
-static gboolean pressed_sequencer_button_mute(ClutterActor *actor, ClutterEvent *event, gpointer data) {
-
+static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer data)   {
+	printf("mute clicked\n");
 	SequencerTrackView *track_view = (SequencerTrackView*) data;
-	JammoTrack* jammotrack;
-	g_object_get(track_view->track_view, "track", &jammotrack, NULL);
-	if (!jammotrack)
-	{
-		printf("JammoTrack false!\n");
-		return FALSE;
-	}
-	//if mute is off, set it on
-	if (!track_view->muted) {
-		animate_buttonpress_down(actor);
-		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), TRUE);
-		//Shade button
-	}
+	JammoPlayingTrack* jammotrack;
 
-	//if mute is on, set it off
-	if (track_view->muted) {
-		animate_buttonpress_release(actor);
-		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), FALSE);
-	}
+	//slider track is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	if (TANGLE_IS_WIDGET(track_view->track_view))
+		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
+	else
+		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
 
-	//Change mute state to opposite
-	track_view->muted = !track_view->muted;
+	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), tangle_button_get_selected(tanglebutton));
 
 	return TRUE;
 }
@@ -338,7 +334,7 @@ gboolean sequencer_volumebar_used (ClutterActor *volume_scroller, gpointer none)
 /**
 Each tracks share one volumebar.
 */
-static gboolean pressed_sequencer_button_volume(ClutterActor *actor, ClutterEvent *event, gpointer data) {
+static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer data) {
 	SequencerTrackView *track_view = (SequencerTrackView*) data;
 
 	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
@@ -354,22 +350,24 @@ static gboolean pressed_sequencer_button_volume(ClutterActor *actor, ClutterEven
 	gfloat current_volume = jammo_playing_track_get_volume(jammotrack);
 	//printf("volume of this track is :%f\n",current_volume);
 
-
 	//When pressing already selected track, hide volume bar
-	JammoPlayingTrack* jammotrack_in_use = g_object_get_data(G_OBJECT(volume_scroller),"track");
-	if (jammotrack == jammotrack_in_use) {
+	if (last_pressed_volume_button==tanglebutton) {
 		clutter_actor_hide(volume_container);
 		g_object_set_data(G_OBJECT(volume_scroller),"track",NULL);
+		last_pressed_volume_button=NULL;
 	}
 
-
+	//Hide last pressed and put new value to volumebar from track
 	else {
 		clutter_actor_show(volume_container);
-		//-80 is height of the visible marker.
-		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-80)*current_volume;
+		//-50 is height of the visible marker.
+		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50)*current_volume;
 		//printf("new place: %f\n",new_place);
 		clutter_actor_animate(CLUTTER_ACTOR(volume_scroller), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-y", new_place, NULL);
 		g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
+		if (last_pressed_volume_button)
+			tangle_button_set_selected(last_pressed_volume_button,FALSE);
+		last_pressed_volume_button=tanglebutton;
 		}
 
 	return FALSE;
@@ -378,7 +376,7 @@ static gboolean pressed_sequencer_button_volume(ClutterActor *actor, ClutterEven
 
 
 bool save_sequencer_state(gchar* outputFilename) {
-
+#ifdef migrating
 	printf("Saving composition\n");
 	FILE *ofp;
 
@@ -421,6 +419,7 @@ bool save_sequencer_state(gchar* outputFilename) {
 	}
 
 	fclose(ofp);
+#endif
 	return FALSE;
 }
 
@@ -517,7 +516,6 @@ void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 /*
 Will make container (TangleWidget) and put it inside scroller.
 Also prepare cursor.
-and make volumesliders FIXME. they are bugging!
 */
 void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_slots, guint64 total_duration, gfloat slot_width, gfloat height) {
 	//Set statics
@@ -546,13 +544,25 @@ void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_sl
 	clutter_actor_set_size(scrolling_actor, 800-x_place_scroller, 0.0);
 
 
+
+	//CURSOR
+	ClutterActor* container_for_texture = tangle_widget_new();
+
+	ClutterActor* triangle_indicator = clutter_texture_new_from_file("/opt/jammo/sequencer/cursor_indicator.png", NULL);
+
+	tangle_widget_add(TANGLE_WIDGET(container_for_texture), triangle_indicator, NULL);
+	//clutter_actor_set_position(triangle_indicator,0,-48.0);
 	//Cursor:
-	ClutterColor red = { 255, 0, 0, 128 };
+	ClutterColor color_for_texture = { 255, 255, 0, 128 };
 	ClutterActor* cursor;
 
-	texture_of_cursor = clutter_rectangle_new_with_color(&red); //this is static, because we want change it's height
-	clutter_actor_set_size(texture_of_cursor, 10.0, 0.0 );
-	cursor = jammo_cursor_new(sequencer, texture_of_cursor);
+	texture_of_cursor = clutter_rectangle_new_with_color(&color_for_texture); //this is static, because we want change it's height
+	clutter_actor_set_size(texture_of_cursor, 11.0, 0.0 );
+	clutter_actor_set_position(texture_of_cursor,8.0,48.0);
+
+	tangle_widget_add(TANGLE_WIDGET(container_for_texture), texture_of_cursor, NULL);
+
+	cursor = jammo_cursor_new(sequencer, container_for_texture);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
 	clutter_actor_set_position(cursor, 0.0, 0.0);
 	clutter_actor_set_size(cursor, width_of_area, 80.0);
@@ -564,7 +574,4 @@ void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_sl
 	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLLING_ACTOR, scrolling_actor, JAMMO_TYPE_CURSOR, cursor);
 	tangle_signal_connect_vault(texture_of_cursor, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
 
-
-	//Hide volumebar
-	clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-volumebar-container"));
 }
