@@ -20,31 +20,25 @@ and some metadata.
 typedef struct {
 	ClutterActor *control_panel;
 	ClutterActor *track_view;
-	ClutterActor *label;
-	ClutterActor *mute_button;
-	ClutterActor *volume_button;
-	gint position;
-	bool muted;
-	bool volume_pressed_down;
-	gint volume_level;
-	char *track_type;
+	gint track_type;
 } SequencerTrackView;
 
 /*
  * Contains all possible SequencerTrackView types
  */
 enum {
-	KEYBOARD_TRACK_VIEW = 1,
+	INSTRUMENT_TRACK_VIEW = 1,
 	DRUM_TRACK_VIEW,
 	SLIDER_TRACK_VIEW,
 	AUDIO_TRACK_VIEW,
-	LOOP_TRACK_VIEW,
+	EDITING_TRACK_VIEW,
 	BACKING_TRACK_VIEW
 };
 
 
 void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_slots, guint64 total_duration, gfloat slot_width, gfloat height);
-ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type);
+ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted);
+ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gint optional_parameter);
 
 //void sequencer_sequencer_track_view_remove_last();
 bool save_sequencer_state();
