@@ -14,8 +14,13 @@
 G_DEFINE_TYPE(JammoCollaborationGroupComposition, jammo_collaboration_group_composition, JAMMO_TYPE_COLLABORATION_GAME);
 
 #include "../meam/jammo-sequencer.h"
-#include "../meam/jammo-backing-track.h"
-#include "../meam/jammo-playing-track.h"
+#include "../meam/jammo-midi.h"
+#include "../meam/jammo-slider-event.h"
+#include "../meam/jammo-loop.h"
+#include "../gems/gems_definitions.h"
+#include "../gems/groupmanager.h"
+#include "../gems/gems.h"
+#include "../gems/collaboration.h"
 
 #define GROUPCOMPOSITIONMAXPLAYERS 4
 
@@ -27,11 +32,9 @@ enum {
 struct _JammoCollaborationGroupCompositionPrivate {
 	// these have to be filled before calling group composition start function
 	int number_of_players;
-	int * sockfds;
 
 	// following are used automatically and do not need to be filled
 	int state;
-	JammoPlayingTrack ** tracks;
 };
 
 // states for group composition
@@ -40,6 +43,72 @@ enum {
 	GROUPCOMPSTATE_ERROR
 };
 
+// callbacks for GEMS
+static void jammo_collaboration_group_composition_midi_remote(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) {
+
+	GList* temp;
+	JammoMidiEvent* n;
+
+	// TODO add list to correct track	
+	printf("jammo-collaboration-group-composition midi callback stub, user id %u, instr id %d, operation %d\n", user_id, instrument_id, operation);
+  
+  printf("Midi list:\n");
+	for (temp = list; temp; temp = temp->next) {
+		n = (temp->data);
+		printf("  %llu ns: note:%d ,type: %s \n", (unsigned long long)n->timestamp,n->note,n->type==0? "start":"stop");
+	}
+}
+
+static void jammo_collaboration_group_composition_slider_remote(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) {
+
+		GList* temp;
+		JammoSliderEvent* n;
+
+	// TODO add list to correct track
+		printf("jammo-collaboration-group-composition slider callback stub, user id %u, instr id %d, operation %d\n", user_id, instrument_id, operation);
+	  printf("Slider event list:\n");
+		for (temp = list; temp; temp = temp->next) {
+			n = (temp->data);
+			printf("  %llu ns: freq:%f ,type: %d \n", (unsigned long long)n->timestamp,n->freq,n->type);
+		}
+}
+
+static void jammo_collaboration_group_composition_add_jammo_sample_button_remote(GObject * game, guint user_id, guint loop_id, guint slot) {
+
+	//JammoCollaborationGroupComposition * collaboration_group_composition = JAMMO_COLLABORATION_GROUP_COMPOSITION(game);
+
+	//ClutterActor* track_view = user_id_to_track(user_id);
+	printf("remote sample, uid %u, loop_id %u, slot %u\n", user_id, loop_id, slot);
+
+	//TODO: loop_id --> sample_button
+	/*JammoSampleButton* sample_button = JAMMO_SAMPLE_BUTTON(jammo_sample_button_new_from_files(
+"/opt/jammo/themes/animal/140/flamingo.png", "/opt/jammo/themes/animal/140/animalw_140_marimba_2.wav"));
+
+	jammo_track_view_add_jammo_sample_button(track_view, sample_button, slot);*/
+}
+
+static void jammo_collaboration_group_composition_remove_jammo_sample_button_remote(GObject * game, guint user_id, guint slot) {
+	//JammoCollaborationGroupComposition * collaboration_group_composition = JAMMO_COLLABORATION_GROUP_COMPOSITION(game);
+
+	//jammo_track_view_remove_jammo_sample_button_from_slot(track_view, slot);
+}
+
+static void jammo_collaboration_group_composition_loop_sync_remote(GObject * game, guint32 user_id, GList * list) {
+	GList* temp;
+	JammoLoop* n;
+
+	// TODO clear existing sample buttons
+
+	//TODO: loop_id --> sample_button
+
+	//TODO: add loops
+	printf("jammo-collaboration-pair-composition loop sync stub, user id %u\n", user_id);
+  printf("Loop list:\n");
+	for (temp = list; temp; temp = temp->next) {
+		n = (temp->data);
+		printf("  loop_id %u, slot %u\n", n->loop_id,n->slot);
+	}
+}
 
 JammoCollaborationGroupComposition* jammo_collaboration_group_composition_new() {
 	return JAMMO_COLLABORATION_GROUP_COMPOSITION(g_object_new(JAMMO_TYPE_COLLABORATION_GROUP_COMPOSITION, NULL));
@@ -106,8 +175,6 @@ static GObject* jammo_collaboration_group_composition_constructor(GType type, gu
 	object = G_OBJECT_CLASS(jammo_collaboration_group_composition_parent_class)->constructor(type, n_properties, properties);
 
 	collaboration_group_composition = JAMMO_COLLABORATION_GROUP_COMPOSITION(object);
-	collaboration_group_composition->priv->sockfds=NULL;
-	collaboration_group_composition->priv->tracks=NULL;
 	collaboration_group_composition->priv->state=GROUPCOMPSTATE_INIT;
 
 	return object;
@@ -140,6 +207,13 @@ static void jammo_collaboration_group_composition_class_init(JammoCollaborationG
 	collaboration_game_class->teacher_exit = jammo_collaboration_group_composition_teacher_exit;
 	collaboration_game_class->create_song_file = jammo_collaboration_group_composition_create_song_file;
 
+	// set callbacks for GEMS
+	gems_set_callback_midi_list(jammo_collaboration_group_composition_midi_remote);
+	gems_set_callback_slider_event_list(jammo_collaboration_group_composition_slider_remote);
+	gems_set_callback_add_loop(jammo_collaboration_group_composition_add_jammo_sample_button_remote);
+	gems_set_callback_remove_loop(jammo_collaboration_group_composition_remove_jammo_sample_button_remote);
+	gems_set_callback_loop_sync(jammo_collaboration_group_composition_loop_sync_remote);
+
 	g_type_class_add_private(gobject_class, sizeof(JammoCollaborationGroupCompositionPrivate));
 }
 
@@ -168,59 +242,33 @@ void jammo_collaboration_group_composition_set_number_of_players(JammoCollaborat
 	}
 }
 
-int jammo_collaboration_group_composition_get_socket(JammoCollaborationGroupComposition * collaboration_group_composition, int index) {
-	if (index>-1 && index<collaboration_group_composition->priv->number_of_players) {
-		return collaboration_group_composition->priv->sockfds[index];
-	}
-	return -1;
+// functions needed in group composition
+// functions for sending event lists
+void jammo_collaboration_group_composition_send_midi_to_group (JammoCollaborationGroupComposition * group_composition) {
+	// TODO get own track from view and send it
+	GList * list =NULL;
+	gems_midi_events_to_track(GEMS_EVENTLIST_REPLACE, 0, list);
 }
 
-// index is needed because everyone has sockets to everyone
-void jammo_collaboration_group_composition_set_socket(JammoCollaborationGroupComposition * collaboration_group_composition, int sockfd, int index) {
-	// allocate memory if not already done
-	if (collaboration_group_composition->priv->sockfds==NULL && collaboration_group_composition->priv->number_of_players>0) {
-		collaboration_group_composition->priv->sockfds= malloc(collaboration_group_composition->priv->number_of_players * sizeof(int));
-
-		if (collaboration_group_composition->priv->sockfds==NULL) {
-			g_critical("Could not allocate memory");
-		}
-	}
-
-	if (index>-1 && index<collaboration_group_composition->priv->number_of_players) {
-		collaboration_group_composition->priv->sockfds[index]=sockfd;
-	}
+void jammo_collaboration_group_composition_send_slider_to_group (JammoCollaborationGroupComposition * group_composition) {
+	// TODO get own track from view and send it
+	GList * list =NULL;
+	gems_slider_events_to_track(GEMS_EVENTLIST_REPLACE, 0, list);
 }
 
-JammoPlayingTrack * jammo_collaboration_group_composition_get_track(JammoCollaborationGroupComposition * collaboration_group_composition, int index) {
-	if (index>-1 && index<collaboration_group_composition->priv->number_of_players) {
-		return collaboration_group_composition->priv->tracks[index];
-	}
-	return NULL;
+void jammo_collaboration_group_composition_loop_sync (JammoCollaborationGroupComposition * group_composition) {
+	// TODO get own loops from view and send them
+	GList * list =NULL;
+	gems_loop_sync(list);
+	jammo_loop_free_glist(&list);
 }
 
-void jammo_collaboration_group_composition_set_track(JammoCollaborationGroupComposition * collaboration_group_composition, JammoPlayingTrack * track, int index) {
-	// allocate memory if not already done
-	if (collaboration_group_composition->priv->tracks==NULL && collaboration_group_composition->priv->number_of_players>0) {
-		collaboration_group_composition->priv->tracks= malloc(collaboration_group_composition->priv->number_of_players * sizeof(JammoPlayingTrack *));
-
-		if (collaboration_group_composition->priv->tracks==NULL) {
-			g_critical("Could not allocate memory");
-		}
-	}
-
-	if (index>-1 && index<collaboration_group_composition->priv->number_of_players) {
-		collaboration_group_composition->priv->tracks[index]=track;
-	}
-}
-
-// function prototypes
+// prototypes
 void jammo_collaboration_group_composition_on_sequencer_stopped_recording(JammoSequencer* sequencer, gpointer data);
 int create_mix_of_group_composition(gpointer data);
 void exit_group_composition(JammoCollaborationGroupComposition * collaboration_group_composition);
 static void clean_up(JammoCollaborationGroupComposition * collaboration_group_composition);
 
-// functions needed in group composition
-
 void jammo_collaboration_group_composition_on_sequencer_stopped_recording(JammoSequencer* sequencer, gpointer data) {
 
 	// uncomment to use object
@@ -271,6 +319,10 @@ void exit_group_composition(JammoCollaborationGroupComposition * collaboration_g
 
 int jammo_collaboration_group_composition_start(JammoCollaborationGroupComposition * collaboration_group_composition) {
 
+	// set group composition to gems
+	gems_components * gems_data = gems_get_data();
+	gems_data->service_collaboration->collaboration_game=G_OBJECT(collaboration_group_composition);
+
 	// this is how to add callback functions to main loop
 	/*g_timeout_add_full(G_PRIORITY_DEFAULT,100,(GSourceFunc)create_mix_of_group_composition,collaboration_group_game,NULL);*/
 
