@@ -119,8 +119,15 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 		sample_button->priv->image_filename = g_strdup(image_filename);
 
 		texture = clutter_texture_new_from_file(image_filename, NULL);
-		tangle_button_set_normal_background_actor(TANGLE_BUTTON(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), texture);
-		g_signal_connect(texture, "size-change", G_CALLBACK(on_size_change), sample_button);
+		if (!texture) {
+			g_warning("Could not create a texture from a file '%s', ignored.", image_filename);
+			
+			g_free(sample_button->priv->image_filename);
+			sample_button->priv->image_filename = NULL;
+		} else {
+			tangle_button_set_normal_background_actor(TANGLE_BUTTON(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), texture);
+			g_signal_connect(texture, "size-change", G_CALLBACK(on_size_change), sample_button);
+		}
 
 		g_object_notify(G_OBJECT(sample_button), "image-filename");
 	}
