@@ -293,13 +293,8 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 		tangle_widget_add(widget, copy_of_sample_button, NULL);
 
 		clutter_actor_animate(copy_of_sample_button, CLUTTER_EASE_OUT_CUBIC, 300, "x", slot * track_view->priv->real_slot_width, "y", 0.0, NULL);
-/*
-		if (sample_button==NULL)
-			printf("sample_button is null\n");
-		gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(sample_button));
-		printf("name is '%s'\n",name);
-		if (name)*/
-		gems_add_new_sample_to_track(jammo_sample_button_get_loop_id(sample_button), slot); //loop_id is actors 'name' field
+
+		gems_add_new_sample_to_track(jammo_sample_button_get_loop_id(sample_button), slot);
 	}
 	
 	track_view->priv->hilighted_start = track_view->priv->hilighted_end = -1.0;
