@@ -159,22 +159,48 @@ static void gst_jammo_slider_base_init (gpointer g_class)
   gst_element_class_set_details (element_class, &gst_jammo_slider_details);
 }
 
+void init_sine_table(gfloat * sine_table, gint size) {
+	gint i;
+	for (i=0;i<size;i++) {
+		sine_table[i]=sinf(i/(gfloat)size * M_PI_M2);
+	}
+}
 
+/* Very simple organ type sound additive synthesis algorithm.*/
+void init_organ_table(gfloat * organ_table, gint size) {
+	gint i;
+	for (i=0;i<size;i++) {
+		organ_table[i]=0.6*(1 * sinf(i/(gfloat)size * M_PI_M2)  + 1.0/6 *sinf((i/(gfloat)size * M_PI_M2)*2) + 1.0/3*sinf((i/(gfloat)size * M_PI_M2)*3) + 1.0/4*sinf((i/(gfloat)size * M_PI_M2)*4)+1.0/3*sinf((i/(gfloat)size * M_PI_M2)*5)+1.0/6*sinf((i/(gfloat)size * M_PI_M2)*6)+1.0/6*sinf((i/(gfloat)size * M_PI_M2)*7)+1.0/4*sinf((i/(gfloat)size * M_PI_M2)*8));
+	}
+}
+
+/* fm synthesis algorithm */
+void init_fm_table(gfloat * fm_table, gint size) {
+	gint i;
+	for (i=0;i<size;i++) {
+		fm_table[i]=( sinf((i/(gfloat)size * M_PI_M2)+0.6*sinf((i/(gfloat)size * M_PI_M2)*8.0)) );
+	}
+}
+
+gfloat sine_value(GstJammoSlider * src, gfloat phase) {
+	while (phase>M_PI_M2) phase-=M_PI_M2;
+	return src->sine_table[(gint)(phase/M_PI_M2*src->table_size)];
+}
 
 /*
 Some day we will have three different instrument using slider.
 Organ and fm_modulation are only for testing.
 */
 
-/* Very simple organ type sound additive synthesis algorithm. This will be changed
-or at least wave should be store in a table instead of multiple sin function calls */
-gfloat organ(gdouble phase){
-return 0.6*(1 * sin(phase)  + 1.0/6 *sin(phase*2) + 1.0/3*sin(phase*3) + 1.0/4*sin(phase*4)+1.0/3*sin(phase*5)+1.0/6*sin(phase*6)+1.0/6*sin(phase*7)+1.0/4*sin(phase*8));
+gfloat organ(GstJammoSlider * src, gdouble phase){
+	while (phase>M_PI_M2) phase-=M_PI_M2;
+	return src->organ_table[(gint)(phase/M_PI_M2*src->table_size)];
 }
 
 
-gfloat fm_modulation(gdouble phase){
-return ( sinf(phase+0.6*sinf(phase*8.0)) );
+gfloat fm_modulation(GstJammoSlider * src, gdouble phase){
+	while (phase>M_PI_M2) phase-=M_PI_M2;
+	return src->fm_table[(gint)(phase/M_PI_M2*src->table_size)];
 }
 
 
@@ -379,6 +405,14 @@ static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g
 	src->blow_loop_start=5000;
 	src->blow_loop_end=40000;
 
+	src->table_size=1024;
+	src->sine_table = g_malloc(sizeof(gfloat)*src->table_size);
+	src->fm_table = g_malloc(sizeof(gfloat)*src->table_size);
+	src->organ_table = g_malloc(sizeof(gfloat)*src->table_size);
+	init_sine_table(src->sine_table, src->table_size);
+	init_organ_table(src->organ_table, src->table_size);
+	init_fm_table(src->fm_table, src->table_size);
+
 }
 
 static void gst_jammo_slider_src_fixate (GstPad * pad, GstCaps * caps)
@@ -470,8 +504,27 @@ static void
 gst_jammo_slider_dispose (GObject * object)
 {
 	GstJammoSlider *src = GST_JAMMO_SLIDER (object);
-	g_free(src->blow_table);
-	jammo_slider_event_free_glist(&(src->eventlist));
+	if (src->blow_table) {
+		g_free(src->blow_table);
+		src->blow_table=NULL;
+	}
+
+	if (src->sine_table) {
+		g_free(src->sine_table);
+		src->sine_table=NULL;
+	}
+	if (src->organ_table) {
+		g_free(src->organ_table);
+		src->organ_table=NULL;
+	}
+	if (src->fm_table) {
+		g_free(src->fm_table);
+		src->fm_table=NULL;
+	}
+	if (src->eventlist) {
+		jammo_slider_event_free_glist(&(src->eventlist));
+	}
+
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -715,14 +768,14 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 	  /* generate sound */ \
 		if(src->state){\
 			if (src->instrument==2)\
-				value = (g##type)( (0.9+fabs(0.1*sin(src->tremolo_phase))) *0.8* scale * (karplus(src) ));\
+				value = (g##type)( (0.9+fabs(0.1*sine_value(src, src->tremolo_phase))) *0.8* scale * (karplus(src) ));\
 			else if (src->instrument==1) {\
 				/* add also blowing sound */ \
-				value = (g##type)( (0.9+fabs(0.1*sin(src->tremolo_phase))) *0.8* scale * (instruments[src->instrument](src->accumulator) )+ BLOW_VOLUME * src->blow_table[(gint)src->blow_accumulator] / (gfloat)G_MAXINT16 );\
-				src->blow_accumulator+=1; \
+				value = (g##type)( (0.9+fabs(0.1*sine_value(src, src->tremolo_phase))) *0.8* scale * (instruments[src->instrument](src, src->accumulator) )+ BLOW_VOLUME * src->blow_table[(gint)src->blow_accumulator] / (gfloat)G_MAXINT16 );\
+				src->blow_accumulator+=src->samplerate/(gfloat)src->blow_file_info.samplerate; \
 			} \
 			else \
-				value = (g##type)( (0.9+fabs(0.1*sin(src->tremolo_phase))) *0.8* scale * (instruments[src->instrument](src->accumulator) ));\
+				value = (g##type)( (0.9+fabs(0.1*sine_value(src, src->tremolo_phase))) *0.8* scale * (instruments[src->instrument](src, src->accumulator) ));\
 		}\
 	  else {\
 	    value=0;\
