@@ -37,7 +37,7 @@ typedef struct _GstJammoSlider GstJammoSlider;
 typedef struct _GstJammoSliderClass GstJammoSliderClass;
 
 typedef void (*JammoSliderProcessFunc) (GstJammoSlider*, guint8 *);
-typedef gfloat (*JammoSliderInstrumentFunc) (gdouble);
+typedef gfloat (*JammoSliderInstrumentFunc) (GstJammoSlider*, gdouble);
 
 /*If you change these:
 -generate freq-table again
@@ -102,6 +102,10 @@ struct _GstJammoSlider {
 	gboolean rounded;
   gint release_counter;
   gfloat release_multiplier;
+	gfloat * sine_table;
+	gfloat * organ_table;
+	gfloat * fm_table;
+	gint table_size;
 
   /* Slider ADSR */
   gfloat attack;
