@@ -20,7 +20,6 @@ enum {
 };
 
 struct _JammoBackingTrackPrivate {
-	GstElement* bin;
 	gchar* filename;
 	guint64 duration;
 };
@@ -75,29 +74,18 @@ static guint64 jammo_backing_track_get_duration(JammoTrack* track) {
 	return JAMMO_BACKING_TRACK(track)->priv->duration;
 }
 
-static GstElement* jammo_backing_track_get_playing_element(JammoPlayingTrack* playing_track) {
-
-	return JAMMO_BACKING_TRACK(playing_track)->priv->bin;
-}
-
-static GObject* jammo_backing_track_constructor(GType type, guint n_properties, GObjectConstructParam* properties) {
-	GObject* object;
+static GstElement* jammo_backing_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
 	JammoBackingTrack* backing_track;
 	GstElement* source;
 	GstElement* decodebin;
 	GstElement* convert;
-	GstPad* pad;
 	
-	object = G_OBJECT_CLASS(jammo_backing_track_parent_class)->constructor(type, n_properties, properties);
+	backing_track = JAMMO_BACKING_TRACK(playing_track);
 
-	backing_track = JAMMO_BACKING_TRACK(object);
-
-	g_assert(backing_track->priv->filename);
+	g_return_val_if_fail(backing_track->priv->filename, NULL);
 
 	preroll(backing_track);
 
-	backing_track->priv->bin = gst_bin_new(NULL);
-
 	source = gst_element_factory_make("filesrc", NULL);
 	g_object_set(source, "location", backing_track->priv->filename, NULL);
 
@@ -105,17 +93,12 @@ static GObject* jammo_backing_track_constructor(GType type, guint n_properties,
 	convert = gst_element_factory_make("audioconvert", NULL);
 	g_signal_connect(decodebin, "new-decoded-pad", G_CALLBACK(on_new_decoded_pad), convert);
 
-	gst_bin_add_many(GST_BIN(backing_track->priv->bin), source, decodebin, convert, NULL);
+	gst_bin_add_many(bin, source, decodebin, convert, NULL);
 	gst_element_link(source, decodebin);
 
-	pad = gst_element_get_pad(convert, "src");
-	gst_element_add_pad(backing_track->priv->bin, gst_ghost_pad_new("src", pad));
-	gst_object_unref(pad);
-
-	return object;
+	return convert;
 }
 
-
 static void jammo_backing_track_finalize(GObject* object) {
 	JammoBackingTrack* backing_track;
 	
@@ -134,14 +117,13 @@ static void jammo_backing_track_class_init(JammoBackingTrackClass* backing_track
 	JammoTrackClass* track_class = JAMMO_TRACK_CLASS(backing_track_class);
 	JammoPlayingTrackClass* playing_track_class = JAMMO_PLAYING_TRACK_CLASS(backing_track_class);
 
-	gobject_class->constructor = jammo_backing_track_constructor;
 	gobject_class->finalize = jammo_backing_track_finalize;
 	gobject_class->dispose = jammo_backing_track_dispose;
 	gobject_class->set_property = jammo_backing_track_set_property;
 	gobject_class->get_property = jammo_backing_track_get_property;
 
 	track_class->get_duration = jammo_backing_track_get_duration;
-	playing_track_class->get_playing_element = jammo_backing_track_get_playing_element;
+	playing_track_class->setup_playing_element = jammo_backing_track_setup_playing_element;
 
 	/**
 	 * JammoBackingTrack:filename:
