@@ -61,9 +61,13 @@ static guint64 jammo_instrument_track_get_duration(JammoTrack* track) {
 	return duration;
 }
 
-static GstElement* jammo_instrument_track_get_playing_element(JammoPlayingTrack* playing_track) {
+static void jammo_instrument_track_set_offline(JammoTrack* track, gboolean offline) {
+	JammoInstrumentTrack* instrument_track;
+	
+	instrument_track = JAMMO_INSTRUMENT_TRACK(track);
 
-	return JAMMO_INSTRUMENT_TRACK(playing_track)->priv->element;
+	jammo_instrument_track_set_live(instrument_track, !offline);
+	jammo_instrument_track_set_realtime(instrument_track, !offline);
 }
 
 static void jammo_instrument_track_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
@@ -102,31 +106,34 @@ static void jammo_instrument_track_finalize(GObject* object) {
 
 static void jammo_instrument_track_dispose(GObject* object) {
 	JammoInstrumentTrack * instrument_track = JAMMO_INSTRUMENT_TRACK(object);
-	g_object_unref(instrument_track->priv->element);
+	if (instrument_track->priv->element) {
+		g_object_unref(instrument_track->priv->element);
+		instrument_track->priv->element=NULL;
+	}
 	G_OBJECT_CLASS(jammo_instrument_track_parent_class)->dispose(object);
 }
 
-static void jammo_instrument_track_receive_message(JammoTrack* track, GstMessage* message) {
+static gboolean jammo_instrument_track_receive_message(JammoTrack* track, GstMessage* message) {
+	gboolean retvalue = FALSE;
 	const GstStructure* structure;
 	gint note;
 
-
 	structure = gst_message_get_structure(message);
 	if (structure && !strcmp(gst_structure_get_name(structure), "sampler")) {
 		note = g_value_get_int(gst_structure_get_value(structure, "note"));
 		//printf("jammo-instrument-track: receive_note %d\n",note);
 		g_signal_emit(track, signals[REPORT_NOTE], 0, note);
+
+		retvalue = TRUE;
 	}
+
+	return retvalue;
 }
 
-static GObject* jammo_instrument_track_constructor(GType type, guint n_properties, GObjectConstructParam* properties) {
-	GObject* object;
+static GstElement* jammo_instrument_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
 	JammoInstrumentTrack* instrument_track;
 
-	object = G_OBJECT_CLASS(jammo_instrument_track_parent_class)->constructor(type, n_properties, properties);
-
-	instrument_track = JAMMO_INSTRUMENT_TRACK(object);
-	instrument_track->priv = G_TYPE_INSTANCE_GET_PRIVATE(instrument_track, JAMMO_TYPE_INSTRUMENT_TRACK, JammoInstrumentTrackPrivate);
+	instrument_track = JAMMO_INSTRUMENT_TRACK(playing_track);
 
 	int instrument_nro = instrument_track->priv->instrument_type;
 	printf ("Type of instrument is: %d\n",instrument_nro);
@@ -151,10 +158,11 @@ static GObject* jammo_instrument_track_constructor(GType type, guint n_propertie
 	}
 
 	g_object_set(G_OBJECT(instrument_track->priv->element), "init-instrument", buffer, NULL);
-
 	g_object_set(G_OBJECT(instrument_track->priv->element), "realtime", FALSE, NULL);
+	
+	gst_bin_add(bin, instrument_track->priv->element);
 
-	return object;
+	return instrument_track->priv->element;
 }
 
 
@@ -164,8 +172,8 @@ static void jammo_instrument_track_class_init(JammoInstrumentTrackClass* instrum
 	JammoPlayingTrackClass* playing_track_class = JAMMO_PLAYING_TRACK_CLASS(instrument_track_class);
 
 	track_class->get_duration = jammo_instrument_track_get_duration;
-	playing_track_class->get_playing_element = jammo_instrument_track_get_playing_element;
-	gobject_class->constructor = jammo_instrument_track_constructor;
+	track_class->set_offline = jammo_instrument_track_set_offline;
+	playing_track_class->setup_playing_element = jammo_instrument_track_setup_playing_element;
 	gobject_class->finalize = jammo_instrument_track_finalize;
 	gobject_class->dispose = jammo_instrument_track_dispose;
 	gobject_class->set_property = jammo_instrument_track_set_property;
